<?php 
/**
 * Study Abroad
 * Destination section
 *
 * This is the template for the content of study_abroad_destination section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_study_abroad_destination_section' ) ) :
    /**
    * Add study_abroad_destination section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_study_abroad_destination_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if study_abroad_destination is enabled
        $enable_study_abroad_destination = $options['destination_enable'];

        if ( true !== $enable_study_abroad_destination ) {
            return false;
        }

        // Get study_abroad_destination section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_study_abroad_destination_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render study_abroad_destination section now.
        corporate_education_pro_render_study_abroad_destination_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_study_abroad_content', 'corporate_education_pro_add_study_abroad_destination_section', 10 );


if ( ! function_exists( 'corporate_education_pro_get_study_abroad_destination_section_details' ) ) :
    /**
    * study_abroad_destination section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input study_abroad_destination section details.
    */
    function corporate_education_pro_get_study_abroad_destination_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // study_abroad_destination type
        $study_abroad_destination_content_type  = $options['destination_content_type'];
        $no_of_destinations  = ! empty( $options['study_abroad_destination_count'] ) ? $options['study_abroad_destination_count'] : 3;

        $content = array();
        switch ( $study_abroad_destination_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['study_abroad_destination_post'] ) )
                    $ids = ( array ) $options['study_abroad_destination_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  
                
          	break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['study_abroad_destination_category'] ) ) {
                    $cat_id = $options['study_abroad_destination_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $no_of_destinations ),
                );
            break;

            case 'excursion':
                $ids = array();
                
                if ( ! empty( $options['study_abroad_destination_excursion'] ) )
                    $ids = ( array ) $options['study_abroad_destination_excursion'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-excursion',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  

            break;

            case 'excursion-category':
                $cat_id = '';
                if ( ! empty( $options['study_abroad_destination_excursion_category'] ) ) {
                    $cat_id = $options['study_abroad_destination_excursion_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-excursion',
                    'posts_per_page'    => absint( $no_of_destinations ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-excursion-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                
            break;

        }

        $posts = get_posts( $args );
        if ( ! empty( $posts ) ) :
            $i = 1;
            foreach ( $posts as $post ) :
                $post_id = $post->ID;
                $img_array = null;
                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'post-thumbnail' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-400x270.jpg';
                    $img_array[1] =  400;
                    $img_array[2] =  270;
                }
                if ( isset( $img_array ) ) {
                    $content[$i]['img_array'] = $img_array;
                }

                $content[$i]['id']       = $post_id;
                $content[$i]['title']    = get_the_title( $post_id );
                $content[$i]['url']      = get_the_permalink( $post_id );
                $content[$i]['excerpt']  = corporate_education_pro_trim_content( 15, $post );
                $i++;
            endforeach;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// study_abroad_destination section content details.
add_filter( 'corporate_education_pro_filter_study_abroad_destination_section_details', 'corporate_education_pro_get_study_abroad_destination_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_study_abroad_destination_section' ) ) :
    /**
    * Start study_abroad_destination section
    *
    * @return string study_abroad_destination content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_study_abroad_destination_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        
        $read_more = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'corporate-education-pro' );
        $content_type  = $options['destination_content_type'];

        $category_link  = '';
        $cat_name       = '';
        if ( $content_type == 'category' ) {
            $category_link  = get_category_link( $options['study_abroad_destination_category'] );
            $cat_name       = get_the_category_by_ID( $options['study_abroad_destination_category'] );
        } elseif ( $content_type == 'excursion-category' ) {
            $category_link  = get_term_link( $options['study_abroad_destination_excursion_category' ], 'tp-excursion-category' );
            $term           = get_term_by('id', $options['study_abroad_destination_excursion_category' ] , 'tp-excursion-category' );
            $cat_name       = $term->name;
        }

        if ( empty( $content_details ) ) {
            return;
        }

        ?>
        <div class="abroad-countries-list col-3">
            <?php foreach ( $content_details as $content_detail ) : ?>
                <div class="hentry">
                    <div class="abroad-countries-wrapper">
                        <figure class="featured-image">
                            <div class="white-shape top"></div>
                            <div class="white-shape top right"></div>
                            <div class="white-shape bottom"></div>
                            <div class="white-shape bottom left"></div>

                            <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>" alt="<?php echo esc_attr( $content_detail['title'] ); ?>"></a>
                        </figure>

                        <div class="entry-container">
                            <h5 class="featured-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                            <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                            <div class="read-more">
                                <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="btn btn-blue-transparent"><?php echo esc_html( $read_more ); ?></a>
                            </div><!-- .read-more -->
                        </div><!-- .entry-container -->
                    </div><!-- .featured-course-wrapper -->
                </div><!-- .hentry -->
            <?php endforeach; ?>
        </div><!-- .abroad-countries-list -->

        <?php if ( ! empty( $category_link ) ) : ?>
            <div class="view-more align-center">
                <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-blue-transparent"><?php printf( '%s ' . esc_html( $cat_name ), esc_html__( 'View all', 'corporate-education-pro' ) ); ?></a>
            </div>
        <?php endif; 
    }
endif;


/**
 * Study Abroad
 * Study guide section
 *
 * This is the template for the content of study_abroad_destination section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_study_abroad_guide_section' ) ) :
    /**
    * Add study_abroad_guide section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_study_abroad_guide_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if study_abroad_guide is enabled
        $enable_study_abroad_guide = $options['study_guide_enable'];

        if ( true !== $enable_study_abroad_guide ) {
            return false;
        }

        // Get study_abroad_guide section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_study_guide_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render study_abroad_guide section now.
        corporate_education_pro_render_study_abroad_guide_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_study_guide_content', 'corporate_education_pro_add_study_abroad_guide_section', 10 );


if ( ! function_exists( 'corporate_education_pro_get_study_abroad_guide_section_details' ) ) :
    /**
    * study_abroad_guide section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input study_abroad_guide section details.
    */
    function corporate_education_pro_get_study_abroad_guide_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // study_abroad_guide type
        $study_guide_content_type  = $options['study_guide_content_type'];
        $no_of_study_guides  = ! empty( $options['study_abroad_guide_count'] ) ? $options['study_abroad_guide_count'] : 6;

        $content = array();
        $args = array();
        switch ( $study_guide_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['study_guide_content_post'] ) )
                    $ids = ( array ) $options['study_guide_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  
                
            break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['study_guide_content_category'] ) ) {
                    $cat_id = $options['study_guide_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $no_of_study_guides ),
                );
            break;

        }

        $posts = get_posts( $args );
        if ( ! empty( $posts ) ) :
            $i = 1;
            foreach ( $posts as $post ) :
                $post_id = $post->ID;
                $content[$i]['icon']    = get_post_meta( $post_id, 'corporate-education-pro-post-icon', true );
                $content[$i]['title']   = get_the_title( $post_id );
                $content[$i]['url']     = get_the_permalink( $post_id );
                $content[$i]['excerpt'] = corporate_education_pro_trim_content( 15, $post );
                $i++;
            endforeach;
        endif;
        wp_reset_postdata();
        
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// study_abroad_guide section content details.
add_filter( 'corporate_education_pro_filter_study_guide_details', 'corporate_education_pro_get_study_abroad_guide_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_study_abroad_guide_section' ) ) :
    /**
    * Start study_abroad_guide section
    *
    * @return string study_abroad_guide content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_study_abroad_guide_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        
        $study_guide_title = ! empty( $options['study_guide_title'] ) ? $options['study_guide_title'] : '';
        $study_guide_sub_title = ! empty( $options['study_guide_sub_title'] ) ? $options['study_guide_sub_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="abroad-study-guidelines" class="page-section">
            <div class="gray-shape top move-up left"></div>
            <div class="gray-shape bottom right move-down"></div>
            <div class="wrapper">
                <?php if ( ! empty( $study_guide_title ) || ! empty( $study_guide_sub_title ) ) : ?>
                    <header class="entry-header align-center">
                        <?php if ( ! empty( $study_guide_title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $study_guide_title ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $study_guide_sub_title ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $study_guide_sub_title ); ?></p>
                        <?php endif; ?>
                    </header>
                <?php endif; ?>

                <div class="entry-content col-3">
                    <?php foreach ( $content_details as $content_detail ) : ?>
                        <div class="hentry">
                            <div class="icon">
                                <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                                    <i class="fa <?php echo esc_attr( $content_detail['icon'] ); ?>"></i>
                                </a>
                            </div><!-- .icon -->
                            <div class="details">
                                <h5 class="featured-title">
                                    <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                                        <?php echo esc_html( $content_detail['title'] ); ?>
                                    </a>
                                </h5>
                                <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                            </div><!-- .details -->
                        </div><!-- .hentry -->
                    <?php endforeach; ?>
                </div><!-- .entry-content -->
            </div><!-- .wrapper -->
        </section><!-- #abroad-study-guidelines -->
    <?php }
endif;