<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

$wp_customize->add_section( 'corporate_education_pro_about', array(
	'title'             => esc_html__( 'About','corporate-education-pro' ),
	'description'       => esc_html__( 'About Section Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_sections_panel',
) );

// about Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['about_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_enable]', array(
	'label'            	=> esc_html__( 'Enable About Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about',
	'type'             	=> 'checkbox',
) );

// about Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_content_type]', array(
	'label'            	=> esc_html__( 'About Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_about_enable',
	'choices'			=> corporate_education_pro_about_content_type(),
) );

// about Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_about_content_post',
	'label'             => esc_html__( 'Input Post Id', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_about',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_page'
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'corporate-education-pro' ),
	'section'        	=> 'corporate_education_pro_about',
	'active_callback' 	=> 'corporate_education_pro_about_content_page',
	'type'				=> 'dropdown-pages'
) );

// about Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_about_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[about_title]', array(
		'selector'            => '#hero-section .wrapper .entry-header h2.entry-title',
		'settings'            => 'corporate_education_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_about_title',
    ) );
}

// about Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_about_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[about_sub_title]', array(
		'selector'            => '#hero-section .wrapper .entry-header p.entry-title-desc',
		'settings'            => 'corporate_education_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_about_sub_title',
    ) );
}

// about Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_excerpt]', array(
	'sanitize_callback'	=> 'wp_kses_post',
	'default'          	=> $options['about_excerpt'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_excerpt]', array(
	'label'            	=> esc_html__( 'Description', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about',
	'type'             	=> 'textarea',
	'active_callback'	=> 'corporate_education_pro_about_content_custom',
) );

// about Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_content_column]', array(
	'default'          	=> $options['about_content_column'],
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_content_column]', array(
	'label'            	=> esc_html__( 'No of Content Columns', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_about_enable',
	'choices'			=> corporate_education_pro_about_content_column(),
) );

// about Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_alphabet]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_alphabet',
	'default'          	=> $options['about_alphabet'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[about_alphabet]', array(
	'label'            	=> esc_html__( 'Set Alphabet', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please input single alphabet', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_about',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_about_enable',
) );

// about alphabet background setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[about_image]', array(
	'default'           => $options['about_image'],
	'sanitize_callback' => 'corporate_education_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'corporate_education_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Alphabet Background Image', 'corporate-education-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'corporate-education-pro' ), 300, 300 ),
		'section'     		=> 'corporate_education_pro_about',
		'active_callback'	=> 'corporate_education_pro_about_content_custom',
) ) );