<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function corporate_education_pro_body_classes( $classes ) {
	$options = corporate_education_pro_get_theme_options();

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Add a class for typography
	$typography = (  $options['theme_typography'] == 'default' ) ? '' :  $options['theme_typography'];
	$classes[] = esc_attr( $typography );

	$body_typography = (  $options['body_theme_typography'] == 'default' ) ? '' :  $options['body_theme_typography'];
	$classes[] = esc_attr( $body_typography );

	// Add a class for layout
	$classes[] = esc_attr( $options['site_layout'] );

	// Add a class for transparent
	$classes[] = ( $options['menu_transparent'] ) ? 'transparent-header' : '';

	// theme layout
	$classes[] = esc_attr( $options['theme_layout'] );

	// menu style
	$classes[] = esc_attr( $options['theme_menu'] );

	// Add a class for sidebar
	$sidebar_position = corporate_education_pro_layout();

	if( is_singular() ) {
		$sidebar = get_post_meta( get_the_id(), 'corporate-education-pro-selected-sidebar', true );
		$post_sidebar = ! empty( $sidebar ) ? $sidebar : 'sidebar-1';
	} else {
		$post_sidebar = 'sidebar-1';
	}

	if ( is_active_sidebar( $post_sidebar ) ) {
		$classes[] = esc_attr( $sidebar_position );
	} else {
		$classes[] = 'no-sidebar';
	}

	if ( true === $options['contact_map_enable'] ) {
		if ( 'shortcode' == $options['map_content_type'] ) {
	    	if ( empty( $options['map_content_shortcode'] ) )
	    		$classes[] = 'map-section-disabled';
	    }
    	elseif ( 'embed' === $options['map_content_type'] ) {
    		if ( empty( $options['map_content_embed'] ) )
    			$classes[] = 'map-section-disabled';
    	}
	} else {
		$classes[] = 'map-section-disabled';
	}

	return $classes;
}
add_filter( 'body_class', 'corporate_education_pro_body_classes' );
