<?php 
/**
 * Latest News section
 *
 * This is the template for the content of latest_news section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_latest_news_section' ) ) :
    /**
    * Add latest_news section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_latest_news_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if latest_news is enabled
        $enable_latest_news = apply_filters( 'corporate_education_pro_section_status', true, 'latest_news_enable' );

        if ( true !== $enable_latest_news ) {
            return false;
        }

        // Get latest_news section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_latest_news_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render latest_news section now.
        corporate_education_pro_render_latest_news_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_latest_news_section', 60 );


if ( ! function_exists( 'corporate_education_pro_get_latest_news_section_details' ) ) :
    /**
    * latest_news section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input latest_news section details.
    */
    function corporate_education_pro_get_latest_news_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // latest_news type
        $latest_news_content_type_1  = $options['latest_news_content_type_1'];
        $no_of_news = ! empty( $options['latest_news_count'] ) ? $options['latest_news_count'] : 4;

        $content = array();
        switch ( $latest_news_content_type_1 ) {
          	case 'demo':
                $title = array(
                    esc_html__( 'Painting and Sketch', 'corporate-education-pro' ),
                    esc_html__( '10 ways to stay healthy this winter', 'corporate-education-pro' ),
                    esc_html__( 'Graduation ceremony 2016', 'corporate-education-pro' ),
                    esc_html__( 'Inter College Basketball', 'corporate-education-pro' ),
                    );
                for ( $i = 0; $i <= 3; $i++ ) :
                    $content['left'][$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/latest-news.jpg';
                    $content['left'][$i]['date']     = esc_html__( '2 DEC 2017', 'corporate-education-pro' );
                    $content['left'][$i]['title']    = $title[$i];
                    $content['left'][$i]['id']       = '';
                    $content['left'][$i]['url']      = '#';
                    $content['left'][$i]['excerpt']  = esc_html__( 'Consectetur adipiscing elite tiam eget augue quis tempor laoreet. Vestibulum purus quam, vestibulum sed malesuada.', 'corporate-education-pro' );
                endfor;
            break;        

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['latest_news_content_category_1'] ) ) {
                    $cat_id = $options['latest_news_content_category_1'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page'  => absint( $options['latest_news_count'] ),
                );
                                            
          	break;

            case 'event-category':
                $cat_id = '';
                if ( ! empty( $options['latest_news_content_event_category_1'] ) ) {
                    $cat_id = $options['latest_news_content_event_category_1'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-event',
                    'posts_per_page'    => absint( $no_of_news ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-event-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                                            
            break;

            case 'recent-event':
                $args = array(
                    'no_found_rows'  => true,
                    'post_type'      => 'tp-event',
                    'posts_per_page'  => absint( $options['latest_news_count'] ),
                );
                                            
            break;

            case 'recent-post':
                $args = array(
                    'no_found_rows'  => true,
                    'post_type'      => 'post',
                    'posts_per_page'  => absint( $options['latest_news_count'] ),
                );
                                            
            break;

        }

        if ( 'demo' != $latest_news_content_type_1 ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'medium_large' );
                    } else {
                        $img_array[0] =  '';
                    }

                    if ( isset( $img_array ) ) {
                        $content['left'][$i]['img_array'] = $img_array;
                    }
                    $content['left'][$i]['id']      = $post_id;
                    $content['left'][$i]['date']    = get_the_date( 'd M Y', $post_id );
                    $content['left'][$i]['title']   = get_the_title( $post_id );
                    $content['left'][$i]['url']     = get_the_permalink( $post_id );
                    $content['left'][$i]['excerpt'] = corporate_education_pro_trim_content( 15, $post  );
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        $latest_news_content_type_2  = $options['latest_news_content_type_2'];

        switch ( $latest_news_content_type_2 ) {
            case 'demo':
                $title = array(
                    esc_html__( 'College Spirits brings festive joy', 'corporate-education-pro' ),
                    esc_html__( 'Library inauguration by College', 'corporate-education-pro' ),
                    esc_html__( 'Best Colleges of 2017', 'corporate-education-pro' ),
                    esc_html__( 'Blood Donation Program 2016', 'corporate-education-pro' ),
                    );
                for ( $i = 0; $i <= 3; $i++ ) :
                    $content['right'][$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/latest-news.jpg';
                    $content['right'][$i]['date']     = esc_html__( '3 DEC 2017', 'corporate-education-pro' );
                    $content['right'][$i]['title']    = $title[$i];
                    $content['right'][$i]['url']      = '#';
                    $content['right'][$i]['excerpt']  = esc_html__( 'Consectetur adipiscing elite tiam eget augue quis tempor laoreet. Vestibulum purus quam, vestibulum sed malesuada.', 'corporate-education-pro' );
                endfor;
            break;        

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['latest_news_content_category_2'] ) ) {
                    $cat_id = $options['latest_news_content_category_2'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page'  => absint( $options['latest_news_count'] ),
                );
                                            
            break;

            case 'event-category':
                $cat_id = '';
                if ( ! empty( $options['latest_news_content_event_category_2'] ) ) {
                    $cat_id = $options['latest_news_content_event_category_2'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-event',
                    'posts_per_page'    => absint( $no_of_news ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-event-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                                            
            break;

            case 'recent-event':
                $args = array(
                    'no_found_rows'  => true,
                    'post_type'      => 'tp-event',
                    'posts_per_page'  => absint( $options['latest_news_count'] ),
                );
                                            
            break;

            case 'recent-post':
                $args = array(
                    'no_found_rows'  => true,
                    'post_type'      => 'post',
                    'posts_per_page'  => absint( $options['latest_news_count'] ),
                );
                                            
            break;
        }

        if ( 'demo' != $latest_news_content_type_2 ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'medium_large' );
                    } else {
                        $img_array[0] =  '';
                    }

                    if ( isset( $img_array ) ) {
                        $content['right'][$i]['img_array'] = $img_array;
                    }
                    $content['right'][$i]['id']      = $post_id;
                    $content['right'][$i]['date']    = get_the_date( 'd M Y', $post_id );
                    $content['right'][$i]['title']   = get_the_title( $post_id );
                    $content['right'][$i]['url']     = get_the_permalink( $post_id );
                    $content['right'][$i]['excerpt'] = corporate_education_pro_trim_content( 15, $post  );
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest_news section content details.
add_filter( 'corporate_education_pro_filter_latest_news_section_details', 'corporate_education_pro_get_latest_news_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_latest_news_section' ) ) :
    /**
    * Start latest_news section
    *
    * @return string latest_news content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_latest_news_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $latest_news_content_type_1  = $options['latest_news_content_type_1'];
        $latest_news_content_type_2  = $options['latest_news_content_type_2'];
        $title_1 = ! empty( $options['latest_news_title_1'] ) ? $options['latest_news_title_1'] : '';
        $sub_title_1 = ! empty( $options['latest_news_sub_title_1'] ) ? $options['latest_news_sub_title_1'] : '';
        $title_2 = ! empty( $options['latest_news_title_2'] ) ? $options['latest_news_title_2'] : '';
        $sub_title_2 = ! empty( $options['latest_news_sub_title_2'] ) ? $options['latest_news_sub_title_2'] : '';

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="latest-news" class="page-section col-2">
            <div class="white-shape top move-up left"></div>
            <div class="white-shape top full-width"></div>
            <div class="white-shape bottom move-down right"></div>

            <div class="wrapper">
                <div class="hentry">
                    <header class="entry-header left">
                        <?php if ( ! empty( $title_1 ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $title_1 ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $sub_title_1 ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $sub_title_1 ); ?></p>
                        <?php endif; ?>
                    </header>

                    <div class="featured-events-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "arrows":true, "autoplay": true, "fade": false, "draggable": false, "vertical" : true }'>
                        <?php foreach ( $content_details['left'] as $content_detail ) : ?>
                            <div class="slick-item <?php if ( empty( $content_detail['img_array'][0] ) ) echo 'no-post-thumbnail'; ?>" data-hoverimage="<?php if ( ! empty( $content_detail['img_array'][0] ) ) echo esc_url( $content_detail['img_array'][0] ); ?>">
                                <div class="event-details">
                                    <div class="black-overlay"></div>
                                    <div class="event-date">
                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                                            <time><?php echo esc_html( $content_detail['date'] ); ?></time>
                                        </a>        
                                    </div><!-- .event-date -->

                                    <div class="entry-container">
                                        <h5 class="featured-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>  
                                        <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                        <?php if ( ! empty( $content_detail['id'] ) ) : ?>
                                            <div class="entry-meta">
                                                <span class="cat-links">
                                                    <?php if ( in_array( $latest_news_content_type_1, array( 'category', 'recent-post' ) ) ) : 
                                                        the_category( '', '', $content_detail['id'] );
                                                    elseif ( in_array( $latest_news_content_type_1 , array(  'recent-event', 'event-category' ) ) ) :
                                                        if ( function_exists( 'tp_education_get_terms' ) ) {
                                                            tp_education_get_terms( 'tp-event-category', $content_detail['id'] );
                                                        }
                                                    endif; ?>
                                                </span><!-- .cat-links -->
                                            </div><!-- .entry-meta -->
                                        <?php elseif ( 'demo' == $latest_news_content_type_1 ) : ?>
                                            <div class="entry-meta">
                                                <span class="cat-links">
                                                    <a href="#"><?php esc_html_e( 'Art', 'corporate-education-pro' ) ?></a>
                                                    <a href="#"><?php esc_html_e( 'Typography', 'corporate-education-pro' ) ?></a>
                                                </span><!-- .cat-links -->
                                            </div><!-- .entry-meta -->
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .event-details -->
                            </div><!-- .slick-item -->
                        <?php endforeach; ?>
                    </div><!-- .featured-events-slider -->
                </div><!-- .hentry -->

                <div class="hentry">
                    <header class="entry-header right">
                        <?php if ( ! empty( $title_2 ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $title_2 ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $sub_title_2 ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $sub_title_2 ); ?></p>
                        <?php endif; ?>
                    </header>

                    <div class="featured-news-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "arrows":true, "autoplay": true, "fade": false, "draggable": false, "vertical" : true }'>
                        <?php foreach ( $content_details['right'] as $content_detail ) : ?>
                            <div class="slick-item <?php if ( empty( $content_detail['img_array'][0] ) ) echo 'no-post-thumbnail'; ?>" data-hoverimage="<?php if ( ! empty( $content_detail['img_array'][0] ) ) echo esc_url( $content_detail['img_array'][0] ); ?>">
                                <div class="news-details">
                                    <div class="black-overlay"></div>
                                    <div class="news-date">
                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                                            <time><?php echo esc_html( $content_detail['date'] ); ?></time>
                                        </a>     
                                    </div><!-- .news-date -->

                                    <div class="entry-container">
                                        <h5 class="featured-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>  
                                        <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                        <?php if ( ! empty( $content_detail['id'] ) ) : ?>
                                            <div class="entry-meta">
                                                <span class="cat-links">
                                                    <?php if ( in_array( $latest_news_content_type_2, array( 'category', 'recent-post' ) ) ) : 
                                                        the_category( '', '', $content_detail['id'] );
                                                    elseif ( in_array( $latest_news_content_type_2 , array(  'recent-event', 'event-category' ) ) ) :
                                                        if ( function_exists( 'tp_education_get_terms' ) ) {
                                                            tp_education_get_terms( 'tp-event-category', $content_detail['id'] );
                                                        }
                                                    endif; ?>
                                                </span><!-- .cat-links -->
                                            </div><!-- .entry-meta -->
                                        <?php elseif ( 'demo' == $latest_news_content_type_2 ) : ?>
                                            <div class="entry-meta">
                                                <span class="cat-links">
                                                    <a href="#"><?php esc_html_e( 'Art', 'corporate-education-pro' ) ?></a>
                                                    <a href="#"><?php esc_html_e( 'Typography', 'corporate-education-pro' ) ?></a>
                                                </span><!-- .cat-links -->
                                            </div><!-- .entry-meta -->
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .news-details -->
                            </div><!-- .slick-item -->
                        <?php endforeach; ?>

                    </div><!-- .featured-news-slider -->
                </div><!-- .hentry -->
            </div><!-- .wrapper -->
        </section><!-- #latest-news -->
    <?php }
endif;