<?php 
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_testimonial_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if testimonial is enabled
        $enable_testimonial = apply_filters( 'corporate_education_pro_section_status', true, 'testimonial_enable' );

        if ( true !== $enable_testimonial ) {
            return false;
        }

        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_testimonial_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render testimonial section now.
        corporate_education_pro_render_testimonial_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_testimonial_section', 90 );


if ( ! function_exists( 'corporate_education_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input testimonial section details.
    */
    function corporate_education_pro_get_testimonial_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // testimonial type
        $testimonial_content_type  = $options['testimonial_content_type'];
        $no_of_testimonial = ! empty( $options['no_of_testimonial'] ) ? $options['no_of_testimonial'] : 4;

        $content = array();
        switch ( $testimonial_content_type ) {
          	case 'demo':
                $title = array (
                    1 => esc_html__( 'Ricky Ortega', 'corporate-education-pro' ),
                    2 => esc_html__( 'Peter Moraes', 'corporate-education-pro' ),
                    3 => esc_html__( 'Milena Newman', 'corporate-education-pro' ),
                    4 => esc_html__( 'Lana Smith', 'corporate-education-pro' ),
                    );
                for ( $i = 1; $i <= 4; $i++ ) :
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/client-0' . $i . '.jpg';
                    $content[$i]['img_array'][1] = 200;
                    $content[$i]['img_array'][2] = 200;
                    $content[$i]['id']       = '';
                    $content[$i]['title']    = $title[$i];
                    $content[$i]['url']      = '#';
                    $content[$i]['excerpt']  = esc_html__( 'Cras posuere, quam non pulvinar con sectetur, odio augue tempor tortor, in egestas felis odio eget leo. Suspendisse viverra orci urna.', 'corporate-education-pro' );
                endfor;
            break;        

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['testimonial_content_post'] ) )
                    $ids = ( array ) $options['testimonial_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 9,
                );  
                
          	break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['testimonial_content_category'] ) ) {
                    $cat_id = $options['testimonial_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $no_of_testimonial ),
                );
            break;

            case 'testimonial':
                $ids = array();
                
                if ( ! empty( $options['testimonial_content_testimonial'] ) )
                    $ids = ( array ) $options['testimonial_content_testimonial'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-testimonial',
                    'post__in'       => $ids,
                    'posts_per_page' => 9,
                );  

            break;

            case 'recent-testimonial':
                $args = array(
                    'post_type'      => 'tp-testimonial',
                    'posts_per_page' => absint( $no_of_testimonial ),
                );  
                
            break;

            
        }

        if ( 'demo' != $testimonial_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'corporate-education-pro-medium' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                        $img_array[1] =  500;
                        $img_array[2] =  500;
                    }
                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }

                    $content[$i]['id']       = $post_id;
                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['url']      = get_the_permalink( $post_id );
                    $content[$i]['excerpt']  = corporate_education_pro_trim_content( 20, $post );
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'corporate_education_pro_filter_testimonial_section_details', 'corporate_education_pro_get_testimonial_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_testimonial_section' ) ) :
    /**
    * Start testimonial section
    *
    * @return string testimonial content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_testimonial_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $title = ! empty( $options['testimonial_title'] ) ? $options['testimonial_title'] : '';
        $sub_title = ! empty( $options['testimonial_sub_title'] ) ? $options['testimonial_sub_title'] : '';
        $testimonial_content_type  = $options['testimonial_content_type'];

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
            <section id="client-testimonial" class="page-section">
                <div class="gray-shape top move-up left"></div>
                <div class="gray-shape bottom move-down right"></div>

                <div class="wrapper">
                    <header class="entry-header align-center">
                        <?php if ( ! empty( $title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $sub_title ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                        <?php endif; ?>
                    </header>

                    <div class="entry-content">
                        <div class="testimonial-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows":false, "autoplay": true, "fade": false, "draggable": false }'>
                            <?php foreach ( $content_details as $content_detail ) : ?>
                                <div class="slick-item">
                                    <div class="testimonial-wrapper">
                                        <div class="white-shape top"></div>
                                        <div class="white-shape top right"></div>
                                        <div class="white-shape bottom"></div>
                                        <div class="white-shape bottom left"></div>

                                        <div class="featured-image">
                                            <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>" alt="<?php echo esc_attr( $content_detail['title'] ); ?>"></a>
                                        </div><!-- .featured-image -->

                                        <div class="testimonial-details">
                                            <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                            <h5 class="featured-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                            <?php if ( in_array( $testimonial_content_type, array( 'testimonial', 'recent-testimonial' ) ) ) : 
                                                if ( has_action( 'tp_testimonial_designation_action' ) ) :
                                                    do_action( 'tp_testimonial_designation_action', $content_detail['id'] );
                                                endif;
                                            elseif ( 'demo' == $testimonial_content_type ) : ?>
                                                <span class="tp-testimonial-designation"><?php esc_html_e( 'Ex Student', 'corporate-education-pro' ); ?></span>
                                            <?php endif; ?>
                                        </div><!-- .testimonial-details -->
                                    </div><!-- .testimonial-wrapper -->
                                </div><!-- .slick-item -->
                            <?php endforeach; ?>
                        </div><!-- .testimonial-slider -->
                    </div><!-- .entry-content -->
                </div><!-- .wrapper -->
            </section><!-- #client-testimonial -->
        <?php }
endif;
